.. oms-cms-doc documentation master file, created by
   sphinx-quickstart on Fri Jul 19 13:04:20 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Добро пожаловать в документацию OMS CMS!
=======================================

OMS - это CMS с открытым исходным кодом, основанная на фреймворке Django, разработанная для гибкости.
Что позволяет вам без проблем расширить ее функционал.
Данная cms позволяет сделать сайт за считанные минуту. Вы можете использовать базовый шаблон или скачать с официального сайта.

.. toctree::
   :maxdepth: 3
   :numbered:


   devdoc/installation
   devdoc/pages
   devdoc/news
   devdoc/languages
   devdoc/contact
   devdoc/menu
   devdoc/soc_networks
   devdoc/partners
   devdoc/gallery
   devdoc/updates


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
